@@ -126,7 +126,7 @@ ResamplingRepeatedCV = R6Class("ResamplingRepeatedCV", inherit = Resampling,
     deep_clone = function(name, value) {
       switch(name,
         "instance" = copy(value),
-        "param_set" = value$clone(deep = TRUE),
+        ".param_set" = value$clone(deep = TRUE),
         value
       )
     }
