@@ -25,32 +25,32 @@ test_that("encapsulation", {
   learner$param_set$values = list(warning_train = 1)
   learner$train(task)
   expect_data_table(learner$log, min.rows = 1L)
-  expect_character(learner$warnings, len = 1L, any.missing = FALSE)
-  expect_character(learner$errors, len = 0L, any.missing = FALSE)
+  expect_class(learner$warnings[[1]], "Mlr3Warning")
+  expect_list(learner$errors, len = 0L)
 
   learner$param_set$values = list(error_train = 1)
   learner$train(task)
   expect_data_table(learner$log, min.rows = 1L)
-  expect_character(learner$warnings, len = 0L, any.missing = FALSE)
-  expect_character(learner$errors, len = 1L, any.missing = FALSE)
+  expect_list(learner$warnings, len = 0L, any.missing = FALSE)
+  expect_class(learner$errors[[1]], "Mlr3Error")
 
   learner$param_set$values = list(warning_predict = 1)
   learner$train(task)
   expect_data_table(learner$log, nrows = 0L)
-  expect_character(learner$warnings, len = 0L, any.missing = FALSE)
-  expect_character(learner$errors, len = 0L, any.missing = FALSE)
+  expect_list(learner$warnings, len = 0L)
+  expect_list(learner$errors, len = 0L)
   expect_prediction(learner$predict(task))
-  expect_character(learner$warnings, len = 1L, any.missing = FALSE)
-  expect_character(learner$errors, len = 0L, any.missing = FALSE)
+  expect_class(learner$warnings[[1]], "Mlr3Warning")
+  expect_list(learner$errors, len = 0L)
 
   learner$param_set$values = list(error_predict = 1)
   learner$train(task)
   expect_data_table(learner$log, nrows = 0L)
-  expect_character(learner$warnings, len = 0L, any.missing = FALSE)
-  expect_character(learner$errors, len = 0L, any.missing = FALSE)
+  expect_list(learner$warnings, len = 0L)
+  expect_list(learner$errors, len = 0L)
   learner$predict(task)
-  expect_character(learner$warnings, len = 0L, any.missing = FALSE)
-  expect_character(learner$errors, len = 1L, any.missing = FALSE)
+  expect_list(learner$warnings, len = 0L)
+  expect_class(learner$errors[[1]], "Mlr3Error")
 })
 
 test_that("encapsulation / resample", {
